import { ConfigProvider, Layout, theme } from "antd";
import DashboardLayout from "./core/components/DashboardLayout";
import {
  darkMode,
  setUserAuthenticated,
  userAuthenticated,
} from "./core/reducers/appSlice";
import { useDispatch, useSelector } from "react-redux";
import SignIn from "./features/Auth/SignIn";
import { useEffect } from "react";
import { myFetch } from "./core/utils/utils";
import MyCenteredSpin from "./shared/components/MyCenteredSpin";
import webSocketService from "core/services/websocketService";

const { defaultAlgorithm, darkAlgorithm } = theme;

function App() {
  const dispatch = useDispatch();

  const isDarkMode = useSelector(darkMode);
  const uAuthenticated = useSelector(userAuthenticated);

  console.info(
    "\n %c LMS %c v1.0.0 %c \n",
    "background-color: #555;color: #fff;padding: 3px 2px 3px 3px;border-radius: 3px 0 0 3px;font-family: DejaVu Sans,Verdana,Geneva,sans-serif;text-shadow: 0 1px 0 rgba(1, 1, 1, 0.3)",
    "background-color: #bc81e0;background-image: linear-gradient(90deg, #e67e22, #9b59b6);color: #fff;padding: 3px 3px 3px 2px;border-radius: 0 3px 3px 0;font-family: DejaVu Sans,Verdana,Geneva,sans-serif;text-shadow: 0 1px 0 rgba(1, 1, 1, 0.3)",
    "background-color: transparent"
  );

  useEffect(() => {
    if (!localStorage.getItem("session")) {
      dispatch(setUserAuthenticated(false));
      return;
    }

    (async () => {
      try {
        const response = await myFetch({
          url: "/user",
          method: "GET",
        });

        if (response) {
          dispatch(setUserAuthenticated(true))
        }
      } catch (error) {}
    })();

    webSocketService.connect();

    return () => {
      webSocketService.disconnect();
    };
  }, []);

  return (
    <Layout style={{ minHeight: "100vh" }}>
      <ConfigProvider
        theme={{
          algorithm: isDarkMode ? darkAlgorithm : defaultAlgorithm,
        }}
      >
        {uAuthenticated == null ? (
          <MyCenteredSpin   />
        ) : uAuthenticated ? (
          <DashboardLayout />
        ) : (
          <SignIn />
        )}
      </ConfigProvider>
    </Layout>
  );
}

export default App;
