import { Avatar, Flex } from "antd";
import {
  isSideMenuCollapsed,
  setIsSideMenuCollapsed,
} from "../SideMenu/sideMenuSlice";
import { useDispatch, useSelector } from "react-redux";
import {
  EditOutlined,
  EyeOutlined,
  LeftOutlined,
  MenuFoldOutlined,
  MenuUnfoldOutlined,
  MoonOutlined,
  SunOutlined,
  UserOutlined,
} from "@ant-design/icons";
import { Link } from "react-router-dom";
import { darkMode, setDarkMode } from "../../reducers/appSlice";
import styles from "./styles.module.css";

type HeaderBarProps = {
  theme?: "light" | "dark";
  onView?: () => void;
  onEdit?: () => void;
  backTo?: string;
};

export default function HeaderBar(props: HeaderBarProps = { theme: "light" }) {
  const dispatch = useDispatch();

  const isCollpased = useSelector(isSideMenuCollapsed);
  const isDarkMode = useSelector(darkMode);

  return (
    <Flex
      justify="space-between"
      align="center"
      style={{
        paddingTop: 12,
        paddingLeft: 12,
        paddingRight: 12,
      }}
    >
      <Flex align="center" gap={16}>
        <div
          className={
            props.theme === "light"
              ? styles.containerLight
              : styles.containerDark
          }
          style={{ borderRadius: 28, padding: 4 }}
        >
          {isCollpased ? (
            <div
              className={styles.iconContainer}
              onClick={() => dispatch(setIsSideMenuCollapsed(false))}
            >
              <MenuUnfoldOutlined className={styles.icon} />
            </div>
          ) : (
            <div
              className={styles.iconContainer}
              onClick={() => dispatch(setIsSideMenuCollapsed(true))}
            >
              <MenuFoldOutlined className={styles.icon} />
            </div>
          )}
        </div>

        {props.backTo && (
          <Link to={props.backTo}>
            <Flex gap={4}>
              <LeftOutlined />
              <span>Back</span>
            </Flex>
          </Link>
        )}
      </Flex>

      <Flex
        align="center"
        className={
          props.theme === "light" ? styles.containerLight : styles.containerDark
        }
        style={{
          borderRadius: 28,
          paddingLeft: 6,
          paddingRight: 6,
          paddingTop: 4,
          paddingBottom: 4,
        }}
        gap={8}
      >
        {props.onView && (
          <div className={styles.iconContainer} onClick={props.onView}>
            <EyeOutlined className={styles.icon} />
          </div>
        )}

        {props.onEdit && (
          <div className={styles.iconContainer} onClick={props.onEdit}>
            <EditOutlined className={styles.icon} />
          </div>
        )}

        {isDarkMode ? (
          <div
            className={styles.iconContainer}
            onClick={() => dispatch(setDarkMode(false))}
          >
            <SunOutlined className={styles.icon} />
          </div>
        ) : (
          <div
            className={styles.iconContainer}
            onClick={() => dispatch(setDarkMode(true))}
          >
            <MoonOutlined className={styles.icon} />
          </div>
        )}
        <Avatar size="default" icon={<UserOutlined />} />
      </Flex>
    </Flex>
  );

  /* return (
    <Header
      style={{
        position: "sticky",
        top: 0,
        zIndex: 10,
        width: "100%",
        display: "flex",
        alignItems: "center",
        padding: 0,
        background: "#fff",
        justifyContent: "space-between",
      }}
    >
      <Button
        type="text"
        icon={isCollpased ? <MenuUnfoldOutlined /> : <MenuFoldOutlined />}
        onClick={() => 
          dispatch(setIsSideMenuCollapsed(!isCollpased))
        }
        style={{ fontSize: 16, width: 64, height: 64 }}
      />

      <div>
        <Link to={Constants.ROUTE_PATHS.LESSIONS.PAGE_EDITOR}>
          <EditOutlined
            style={{
              fontSize: 20,
              width: 64,
              height: 64,
              justifyContent: "center",
            }}
            onClick={() => dispatch(setEditorActive(!isEditorActive))}
          />
        </Link>

        {isDarkMode ? (
          <SunOutlined
            style={{
              fontSize: 20,
              width: 64,
              height: 64,
              justifyContent: "center",
            }}
            onClick={() => dispatch(setDarkMode(false))}
          />
        ) : (
          <MoonOutlined
            style={{
              fontSize: 20,
              width: 64,
              height: 64,
              justifyContent: "center",
            }}
            onClick={() => {
              dispatch(setDarkMode(true));
            }}
          />
        )}
      </div>
    </Header>
  ); */
}
