import { BrowserTabSession, Constants } from "core/utils/utils";

interface WebSocketMessage {
  type: string;
  payload: any;
}

class WebSocketService {
  private url: string;
  private socket: WebSocket | null = null;
  private reconnectInterval: number = 10000; // 5 Sekunden
  private handlers: Record<string, (payload: any) => void> = {};

  constructor(url: string) {
    this.url = `${url}?auth=${localStorage.getItem(
      "session"
    )}&bts=${BrowserTabSession}`;
  }

  public connect(): void {
    this.socket = new WebSocket(this.url);

    this.socket.onopen = () => {
      console.log("WebSocket connected");
    };

    this.socket.onmessage = (event: MessageEvent) => {
      const data: WebSocketMessage = JSON.parse(event.data);
      this.handleMessage(data);
    };

    this.socket.onclose = () => {
      console.log("WebSocket disconnected. Reconnecting...");
      setTimeout(() => this.connect(), this.reconnectInterval);
    };

    this.socket.onerror = (error: Event) => {
      console.error("WebSocket error:", error);
    };
  }

  private handleMessage(data: WebSocketMessage): void {
    const { type, payload } = data;
    if (this.handlers[type]) {
      this.handlers[type](payload);
    }
  }

  public onMessage(type: string, handler: (payload: any) => void): void {
    this.handlers[type] = handler;
  }

  public send(type: string, payload: any): void {
    const message: WebSocketMessage = { type, payload };
    if (this.socket) {
      this.socket.send(JSON.stringify(message));
    }
  }

  public disconnect(): void {
    if (this.socket) {
      this.socket.close();
    }
  }
}

const webSocketService = new WebSocketService(Constants.WS_ADDRESS);
export default webSocketService;
