import {
  Avatar,
  Button,
  Card,
  Divider,
  Flex,
  Form,
  Input,
  Typography,
} from "antd";
import HeaderBar from "../../core/components/Header";
import MyBanner from "../../shared/components/MyBanner";
import { MyContainer } from "../../shared/components/MyContainer";
import { SaveOutlined } from "@ant-design/icons";
import MyUpload from "shared/components/MyUpload";
import { Constants } from "core/utils/utils";
import ColorPicker from "antd/es/color-picker";
import MyMiddleCard from "shared/components/MyMiddleCard";
import Meta from "antd/es/card/Meta";

export function AccountSettingsAdmin() {
  return (
    <>
      <MyBanner
        title="Account Settings"
        subtitle="MANAGE"
        headerBar={<HeaderBar />}
      />

      <MyMiddleCard title="My Profile">
        <Flex vertical gap={16}  >
          <Card
            styles={{
              body: {
                padding: 16,
              },
            }}
          >
            <Meta
              avatar={
                <Avatar
                  src={`${Constants.STATIC_CONTENT_ADDRESS}/demo/lesson_thumbnail.webp`}
                  size={56}
                />
              }
              title="Jorg Kreith"
              description="Lead"
            />
          </Card>
          <Card
            styles={{
              body: {
                padding: 16,
                paddingBottom: 0,
              },
            }}
          >
            <Meta title="Personal Information" />
            <Form layout="vertical" style={{ marginTop: 24 }}>
              <Flex gap={16}>
                <Flex flex={1}>
                  <Form.Item label="First name" name="firstName" style={{width: "100%"}}>
                    <Input defaultValue="Jorg" />
                  </Form.Item>
                </Flex>
                <Flex flex={1}>
                  <Form.Item label="Last name" name="lastName" style={{width: "100%"}}>
                    <Input defaultValue="Kreth" />
                  </Form.Item>
                </Flex>
              </Flex>
              <Form.Item label="Email" name="email">
                <Input defaultValue="julian@xx.com" />
              </Form.Item>
              <Form.Item style={{ textAlign: 'right' }}>
                <Button
                  type="primary"
                  icon={<SaveOutlined />}
                  htmlType="submit"
                >
                  Update
                </Button>
              </Form.Item>
            </Form>
          </Card>
        </Flex>
      </MyMiddleCard>
    </>
  );
}

export default function AccountSettings() {
  return (
    <>
      <MyBanner
        title="Account Settings"
        subtitle="MANAGE"
        headerBar={<HeaderBar />}
      />

      <MyMiddleCard title="My Profile">
        <Flex vertical gap={16} style={{ paddingBottom: 16 }}>
          <Card
            styles={{
              body: {
                padding: 16,
              },
            }}
          >
            <Meta
              avatar={
                <Avatar
                  src={`${Constants.STATIC_CONTENT_ADDRESS}/demo/lesson_thumbnail.webp`}
                  size={56}
                />
              }
              title="Jorg Kreith"
              description="Lead"
            />
          </Card>
          <Card
            styles={{
              body: {
                padding: 16,
              },
            }}
          >
            <Meta title="Personal Information" />
            <Flex gap={16} style={{ marginTop: 24 }}>
              <Flex vertical gap={24} flex={1}>
                <Flex gap={8} vertical>
                  <TitleText>First name</TitleText>
                  <ValueText>Jorg</ValueText>
                </Flex>
                <Flex gap={8} vertical>
                  <TitleText>Email</TitleText>
                  <ValueText>julian@xx.com</ValueText>
                </Flex>
              </Flex>
              <Flex vertical gap={24} flex={1}>
                <Flex gap={8} vertical>
                  <TitleText>Last name</TitleText>
                  <ValueText>Kreth</ValueText>
                </Flex>
              </Flex>
            </Flex>
          </Card>
        </Flex>
      </MyMiddleCard>
    </>
  );
}

/*
// TODO: sessions table

  <Card
    styles={{
      body: {
        padding: 16,
      },
    }}
  >
    <Meta title="Sessions" />
    <Typography.Text>// Todoo</Typography.Text>
  </Card>
*/

function TitleText({ children }: { children: React.ReactNode }) {
  return (
    <Typography.Text style={{ fontSize: 16, opacity: 0.4 }}>
      {children}
    </Typography.Text>
  );
}

function ValueText({ children }: { children: React.ReactNode }) {
  return <Typography.Text style={{ fontSize: 16 }}>{children}</Typography.Text>;
}
