import { Button, Flex } from "antd";
import { CheckOutlined } from "@ant-design/icons";
import HeaderBar from "../../../core/components/Header";
import { useLocation, useNavigate, useParams } from "react-router-dom";
import { Constants } from "../../../core/utils/utils";
import React from "react";
import MySpin from "shared/components/MySpin";
import MyErrorResult from "shared/components/MyResult";
import MyEmpty from "shared/components/MyEmpty";
import { useGetLessonContentsQuery } from "core/services/lessons";
import MyMiddleCard from "shared/components/MyMiddleCard";
import { Converter } from "../converter";

const LessonContents: React.FC = () => {
  const { lessonId } = useParams();

  const { data, error, isLoading } = useGetLessonContentsQuery(
    lessonId as string,
    {
      refetchOnMountOrArgChange: true,
    }
  );

  if (isLoading) return <MySpin />;
  if (error) return <MyErrorResult />;

  if (!data || data.length === 0) return <MyEmpty />;

  return (
    <>
      {data.map((lessonContent) => (
        <div key={lessonContent.Id} style={{ paddingBottom: 6 }}>
          <Converter mode="view" lessonContent={lessonContent} />
        </div>
      ))}
    </>
  );
};

export default function LessonPage() {
  const location = useLocation();
  const navigate = useNavigate();

  return (
    <>
      <HeaderBar
        theme="light"
        backTo={Constants.ROUTE_PATHS.LESSIONS.ROOT}
        onEdit={() => navigate(`${location.pathname}/editor`)}
      />

      <MyMiddleCard>
        <LessonContents />

        <Flex justify="right">
          <Button type="primary" icon={<CheckOutlined />}>
            Finish lesson
          </Button>
        </Flex>
      </MyMiddleCard>
    </>
  );
}
