import { DndContext, DragEndEvent, useDroppable } from "@dnd-kit/core";
import {
  verticalListSortingStrategy,
  SortableContext,
} from "@dnd-kit/sortable";
import SortableEditorItem from "./SortableEditorItem";
import { store } from "core/store/store";

import {
  restrictToVerticalAxis,
  restrictToWindowEdges,
} from "@dnd-kit/modifiers";
import { currentLessonId, onDragHandler } from "./lessonPageEditorSlice";
import { LessonContent } from "core/types/lesson";
import { useUpdateLessonContentPositionMutation } from "core/services/lessons";
import { useSelector } from "react-redux";

const Droppable = ({ items }: { items: LessonContent[] }) => {
  const droppableID = "editorComponentArea";
  const { setNodeRef } = useDroppable({ id: droppableID });
  const currentLnId = useSelector(currentLessonId);

  const [reqUpdateLessonContentPosition] =
    useUpdateLessonContentPositionMutation();

  const itemIDs = items.map((item) => item.Id);

  const handleDragEnd = (event: DragEndEvent) => {
    console.log("drag end", event);

    if (!event.over) return;

    const activeId = event.active.id;
    const overId = event.over.id;

    if (activeId === overId) return;

    let oldIndex = itemIDs.findIndex((item) => item === activeId);
    let newIndex = itemIDs.findIndex((item) => item === overId);

    // store.dispatch(onDragHandler({ activeId, overId }));

    store.dispatch(onDragHandler({ oldIndex, newIndex }));

    try {
      reqUpdateLessonContentPosition({
        lessonId: currentLnId,
        contentId: activeId,
        newPosition: newIndex + 1,
      });
    } catch (err) {
      console.error(err);
    }
  };

  return (
    <DndContext
      modifiers={[restrictToVerticalAxis, restrictToWindowEdges]}
      onDragEnd={handleDragEnd}
    >
      <SortableContext
        id={droppableID}
        items={itemIDs}
        strategy={verticalListSortingStrategy}
      >
        <div ref={setNodeRef}>
          {items.map((item) => (
            <SortableEditorItem key={`${droppableID}_${item.Id}`} item={item} />
          ))}
        </div>
      </SortableContext>
    </DndContext>
  );
};
/*
function handleDragEnd(event: DragEndEvent) {
  console.log("drag end", event);

  if (!event.over) return;

  const activeId = event.active.id;
  const overId = event.over.id;

  store.dispatch(onDragHandler({ activeId, overId }));
} */

export default Droppable;
