import { defaultAnimateLayoutChanges, useSortable } from "@dnd-kit/sortable";
import { CSS } from "@dnd-kit/utilities";
import {
  HolderOutlined,
  DeleteOutlined,
  CameraOutlined,
  FolderOpenOutlined,
} from "@ant-design/icons";
import { Flex } from "antd";
import {
  currentLessonId,
  deleteLessonContent,
  updateLessonContent,
} from "./lessonPageEditorSlice";
import { useDispatch, useSelector } from "react-redux";
import { getComponentByType } from "../components";
import { LessonContent } from "core/types/lesson";
import "./styles.module.css";
import { Converter } from "../converter";
import { useDeleteLessonContentMutation } from "core/services/lessons";

const animateLayoutChanges = (args: any) =>
  args.isSorting || args.wasDragging ? defaultAnimateLayoutChanges(args) : true;

const SortableEditorItem = (props: { item: LessonContent }) => {
  const lnContent = props.item;
  const { attributes, listeners, setNodeRef, transform, transition } =
    useSortable({ id: lnContent.Id, animateLayoutChanges });

  const dispatch = useDispatch();

  const component = getComponentByType(lnContent.Type);

  const [reqDeleteLessonContent] = useDeleteLessonContentMutation();
  const currentLnId = useSelector(currentLessonId);

  if (!component) {
    return null;
  }

  return (
    <div
      style={{
        transform: CSS.Translate.toString(transform),
        transition,
      }}
      ref={setNodeRef}
      {...attributes}
    >
      <Flex key={lnContent.Id}>
        <HolderOutlined
          style={{
            paddingLeft: 8,
            paddingRight: 8,
            touchAction: "none",
            cursor: "move",
          }}
          {...listeners}
        />
        <Converter
          mode="edititable"
          lessonContent={lnContent}
          onEdit={(data) => {
            console.log("edit", lnContent.Id, data);

            dispatch(
              updateLessonContent({
                id: lnContent.Id,
                data: data,
              })
            );
          }}
        />

        <Flex vertical justify="center">
          {component.uploadImage ? (
            <div className="EditorActionIcon">
              <CameraOutlined />
            </div>
          ) : null}
          {component.uploadFileTypes ? (
            <div className="EditorActionIcon">
              <FolderOpenOutlined className="EditorActionIcon" />{" "}
            </div>
          ) : null}
          <div className="EditorActionIcon">
            <DeleteOutlined
              className="EditorActionIcon"
              onClick={() => {
                console.log("delete", lnContent.Id);
                dispatch(deleteLessonContent(lnContent.Id));

                try {
                  reqDeleteLessonContent({
                    lessonId: currentLnId,
                    contentId: lnContent.Id,
                  });
                } catch (err) {
                  console.error(err);
                }
              }}
            />
          </div>
        </Flex>
      </Flex>
    </div>
  );
};

export default SortableEditorItem;
