import { LessonContent } from "core/types/lesson";
import { getTypeByName } from "./components";
import { Button, Input, Typography } from "antd";
import { useUpdateLessonContentMutation } from "core/services/lessons";
import { useSelector } from "react-redux";
import { currentLessonId } from "./LessonPageEditor/lessonPageEditorSlice";
import { useRef } from "react";
import MyUpload from "shared/components/MyUpload";

export function Converter({
  mode,
  lessonContent,
  onEdit,
}: {
  mode: "view" | "edititable";
  lessonContent: LessonContent;
  onEdit?: (newData: string) => void;
}) {
  const lessonId = useSelector(currentLessonId);

  const [reqUpdateLessonContent] = useUpdateLessonContentMutation();

  const debounceRef = useRef<null | NodeJS.Timeout>(null);

  switch (lessonContent.Type) {
    case getTypeByName("Header"):
      if (mode === "view") {
        return (
          <div
            style={{ fontWeight: "bold", fontSize: 24, wordBreak: "break-all" }}
          >
            {lessonContent.Data}
          </div>
        );
      }

      return (
        <Typography.Title
          editable={{
            triggerType: "text" as any,
            onChange: (event) => {
              onEdit?.(event);

              try {
                reqUpdateLessonContent({
                  lessonId: lessonId,
                  contentId: lessonContent.Id,
                  data: event,
                });
              } catch (err) {
                console.error(err);
              }
            },
          }}
          level={1}
          style={{
            margin: 0,
            width: "100%",
          }}
        >
          {lessonContent.Data}
        </Typography.Title>
      );
    case getTypeByName("Text"):
      if (mode === "view") {
        return (
          <div style={{ fontSize: 16, wordBreak: "break-all" }}>
            {lessonContent.Data}
          </div>
        );
      }

      return (
        <Input.TextArea
          variant="borderless"
          placeholder="Input text here"
          style={{ width: "100%" }}
          value={lessonContent.Data}
          onChange={(event) => {
            console.log("edit");

            onEdit?.(event.target.value);

            if (debounceRef.current) {
              clearTimeout(debounceRef.current);
            }

            debounceRef.current = setTimeout(() => {
              try {
                reqUpdateLessonContent({
                  lessonId: lessonId,
                  contentId: lessonContent.Id,
                  data: event.target.value,
                });
              } catch (err) {
                console.error(err);
              }
            }, 1000);
          }}
        />
      );
    case getTypeByName("Image"):
      console.log("image", lessonContent.Data);

      if (mode === "view" && lessonContent.Data === "") {
        return (
          <div
            style={{
              position: "relative",
              height: 120,
              width: "100%",
              backgroundColor: "#EBEBEB",
              marginRight: 8,
            }}
          >
            <div
              style={{
                position: "absolute",
                top: "50%",
                left: "50%",
                transform: "translate(-50%, -50%)",
              }}
            >
              No image provided
            </div>
          </div>
        );
      }

      if (lessonContent.Data === "") {
        return (
          <div
            style={{
              position: "relative",
              height: 120,
              width: "100%",
              backgroundColor: "#EBEBEB",
              margin: "12px 12px 12px 0",
            }}
          >
            <div
              style={{
                display: "flex",
                flexDirection: "column",
                alignItems: "center",
                position: "absolute",
                top: "50%",
                left: "50%",
                transform: "translate(-50%, -50%)",
              }}
            >
              <span>Choose image from</span>
              
              <MyUpload>
                <Button type="link">Gallery</Button>
              </MyUpload>
            </div>
          </div>
        );
      }

      return (
        <>
          <img src={lessonContent.Data} alt="img" style={{ width: "100%" }} />
        </>
      );
    case getTypeByName("YouTube"):
      return (
        <div style={{ fontWeight: "700", fontSize: 20, width: "100%" }}>
          {lessonContent.Data}
        </div>
      );
    case getTypeByName("Video"):
      return <div style={{ fontSize: 14, width: "100%" }}>Not implemented</div>;
    case getTypeByName("Iframe"):
      return <div style={{ fontSize: 14, width: "100%" }}>Not implemented</div>;
    case getTypeByName("Banner"):
      return <div style={{ fontSize: 14, width: "100%" }}>Not implemented</div>;

    default:
      return <div>Unknown type</div>;
  }
}
