import { Button, Card, Divider, Flex, Form, Input, Typography } from "antd";
import HeaderBar from "../../core/components/Header";
import MyBanner from "../../shared/components/MyBanner";
import { MyContainer } from "../../shared/components/MyContainer";
import { SaveOutlined } from "@ant-design/icons";
import MyUpload from "shared/components/MyUpload";
import { Constants } from "core/utils/utils";
import ColorPicker from "antd/es/color-picker";

export default function Settings() {
  return (
    <>
      <MyBanner title="Settings" subtitle="MANAGE" headerBar={<HeaderBar />} />

      <MyContainer>
        <Flex vertical gap={16} style={{ paddingBottom: 16 }}>
          <Card
            styles={{
              body: {
                padding: 16,
              },
            }}
          >
            <Flex vertical gap={2}>
              <Form>
                <Flex justify="space-between" align="center">
                  <Typography.Title level={5} style={{ margin: 0 }}>
                    Branding
                  </Typography.Title>
                  <Button
                    icon={<SaveOutlined />}
                    type="text"
                    shape="circle"
                    size="large"
                    htmlType="submit"
                  />
                </Flex>
                <Divider style={{ margin: 0, padding: 0 }} />

                <Flex gap={32}>
                  <Flex vertical>
                    <Typography.Text style={{ fontSize: 16 }}>
                      Primary Color
                    </Typography.Text>
                    <Form.Item name="primaryColor">
                      <ColorPicker
                        defaultValue="#1677ff"
                        size="small"
                        showText
                      />
                    </Form.Item>
                  </Flex>
                  <Flex vertical>
                    <Typography.Text style={{ fontSize: 16 }}>
                      Company name
                    </Typography.Text>
                    <Form.Item name="companyName">
                      <Input defaultValue="Jannex" />
                    </Form.Item>
                  </Flex>
                  <Flex vertical>
                    <Typography.Text style={{ fontSize: 16 }}>
                      Subdomain
                    </Typography.Text>
                    <Form.Item name="subdomain">
                      <Input addonBefore="https://" addonAfter=". jannex . de" defaultValue="mysite" />
                    </Form.Item>
                  </Flex>
                  <Flex vertical>
                    <Typography.Text style={{ fontSize: 16 }}>
                      Logo
                    </Typography.Text>
                    <MyUpload
                      action={`/changeCompanyLogo`}
                      onChange={(info) => {
                        if (info.file.status === "done") {
                          //onThumbnailChanged?.();
                          console.log("done");
                        }
                      }}
                      imgCropProps={{
                        aspect: 1 / 1,
                        children: <></>,
                      }}
                    >
                      <img
                        src={`${Constants.STATIC_CONTENT_ADDRESS}/demo/lesson_thumbnail.webp`}
                        alt="Company Logo"
                        style={{
                          width: 128,
                          maxHeight: 128,
                          padding: 4,
                          borderRadius: 4,
                          border: "1px solid #ddd",
                        }}
                      />
                    </MyUpload>
                  </Flex>
                </Flex>
                <Flex vertical>
                  <Typography.Text style={{ fontSize: 16 }}>
                    Thumbnail
                  </Typography.Text>
                  <MyUpload
                    action={`/changeCompanyLogo`}
                    onChange={(info) => {
                      if (info.file.status === "done") {
                        //onThumbnailChanged?.();
                        console.log("done");
                      }
                    }}
                    imgCropProps={{
                      aspect: 22 / 9,
                      children: <></>,
                    }}
                  >
                    <img
                      src={`${Constants.STATIC_CONTENT_ADDRESS}/demo/lesson_thumbnail.webp`}
                      alt="Thumbnail"
                      style={{
                        width: "100%",
                        height: 228,
                        objectFit: "cover",
                        padding: 4,
                        borderRadius: 4,
                        border: "1px solid #ddd",
                      }}
                    />
                  </MyUpload>
                </Flex>
              </Form>
            </Flex>
          </Card>
        </Flex>
      </MyContainer>
    </>
  );
}
