import { PlusOutlined } from "@ant-design/icons";
import { Button, Card, Checkbox, Flex, Form, Input } from "antd";
import HeaderBar from "core/components/Header";
import { Constants } from "core/utils/utils";
import MyMiddleCard from "shared/components/MyMiddleCard";

type FieldType = {
  firstName: string;
  lastName: string;
  email: string;
  changePasswordOnFirstLogin: boolean;
  password?: string;
  sendInvitationEmail: boolean;
};

export default function TeamCreateUser() {
  return (
    <>
      <HeaderBar
        theme="light"
        backTo={Constants.ROUTE_PATHS.ORGANIZATION_TEAM}
      />

      <MyMiddleCard title="Create User">
        <Form layout="vertical" requiredMark={false}>
          <Form.Item<FieldType>
            label="First Name"
            name="firstName"
            rules={[{ required: true, message: "Please input first name!" }]}
          >
            <Input placeholder="First Name" />
          </Form.Item>

          <Form.Item<FieldType>
            label="Last Name"
            name="lastName"
            rules={[{ required: true, message: "Please input last name!" }]}
          >
            <Input placeholder="Last Name" />
          </Form.Item>

          <Form.Item<FieldType>
            label="Email"
            name="email"
            rules={[
              { required: true, message: "Please input email!", type: "email" },
            ]}
          >
            <Input placeholder="Email" />
          </Form.Item>

          <Form.Item<FieldType>
            name="changePasswordOnFirstLogin"
            valuePropName="checked"
          >
            <Checkbox>Change Password on First Login</Checkbox>
          </Form.Item>

          <Form.Item<FieldType>
            label="Password"
            name="password"
            rules={[{ required: true, message: "Please input password!" }]}
          >
            <Input.Password placeholder="Password" />
          </Form.Item>

          <Form.Item<FieldType>
            name="sendInvitationEmail"
            valuePropName="checked"
          >
            <Checkbox>Send an invitation email to the user</Checkbox>
          </Form.Item>

          <Flex justify="end">
            <Button type="primary" icon={<PlusOutlined />}>
              Create User
            </Button>
          </Flex>
        </Form>
      </MyMiddleCard>
    </>
  );
}
