import MyTable from "shared/components/MyTable";
import HeaderBar from "../../core/components/Header";
import MyBanner from "../../shared/components/MyBanner";
import { MyContainer } from "../../shared/components/MyContainer";
import { Button, Flex } from "antd";
import { UserAddOutlined } from "@ant-design/icons";
import { Link } from "react-router-dom";
import { Constants } from "core/utils/utils";
import { useGetTeamQuery } from "core/services/team";
import MyErrorResult from "shared/components/MyResult";

const TeamList: React.FC = () => {
  const { data, error, isLoading } = useGetTeamQuery(undefined, {
    refetchOnMountOrArgChange: true,
  });

  const getTableContent = () => {
    let items = [
      {
        title: "First name",
        dataIndex: "firstName",
        key: "firstName",
      },
      {
        title: "Last name",
        dataIndex: "lastName",
        key: "lastName",
      },
      {
        title: "Email",
        dataIndex: "email",
        key: "email",
      },
      {
        title: "Role",
        dataIndex: "role",
        key: "role",
      },
      {
        title: "Status",
        dataIndex: "status",
        key: "status",
      },
      {
        title: "Actions",
        dataIndex: "actions",
        key: "actions",
      },
    ];

    return items;
  };

  const getTableItems = () => {
    let items = [] as any[];

    if (!data) return items;

    data.forEach((item) => {
      items.push({
        key: item.Id,
        firstName: item.FirstName,
        lastName: item.LastName,
        email: item.Email,
        role: item.Role,
        status: item.Status,
      });
    });

    return items;
  }

  if (error) return <MyErrorResult />;

  return (
    <MyTable loading={isLoading} columns={getTableContent()} dataSource={getTableItems()} pagination={false} />
  );
};

export default function Team() {
  return (
    <>
      <MyBanner title="Team" subtitle="MANAGE" headerBar={<HeaderBar />} />

      <MyContainer
        style={{
          display: "flex",
          flexDirection: "column",
          gap: 16,
        }}
      >
        <Flex justify="end">
          <Link to={Constants.ROUTE_PATHS.ORGANIZATION_TEAM_CREATE_USER}>
            <Button icon={<UserAddOutlined />}>Invite new member</Button>
          </Link>
        </Flex>

        <TeamList />
      </MyContainer>
    </>
  );
}
