import ImgCrop, { ImgCropProps } from "antd-img-crop";
import Upload from "antd/es/upload/Upload";
import { getApiHeader } from "core/helper/api";
import { Constants } from "core/utils/utils";

export default function MyUpload({
  children,
  imgCropProps,
  accept = Constants.ACCEPTED_IMAGE_FILE_TYPES.join(","),
  maxCount = 1,
  showUploadList = false,
  headers = getApiHeader(),
  action,
  onChange,
}: {
  children: React.ReactNode;
  imgCropProps?: ImgCropProps;
  accept?: string;
  maxCount?: number;
  showUploadList?: boolean;
  headers?: any;
  action?: string;
  onChange?: (info: any) => void;
}) {
  const beforeUpload = (file: File) => {
    if (!Constants.ACCEPTED_IMAGE_FILE_TYPES.includes(file.type)) {
      console.error("File typ not allowed!");
      return false;
    }

    if (file.size > Constants.MAX_IMAGE_SIZE) {
      console.error("Image is to large!");
      return false;
    }

    return true;
  };

  return (
    <ImgCrop 
      {...imgCropProps}
      rotationSlider
    >
      <Upload
        accept={accept}
        maxCount={maxCount}
        showUploadList={showUploadList}
        headers={headers}
        action={`${Constants.API_ADDRESS}${action}`}
        onChange={onChange}
        beforeUpload={beforeUpload}

      >
        {children}
      </Upload>
    </ImgCrop>
  );
}
